# AggQuery

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**aggregate_hash** | **str** | hash of the aggregated repo to fetch information for.  | 
**success** | **bool** | If set to a value, only return the CI reports with the specified vote. If not set, return all CI reports.  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


